@@ -24,10 +24,12 @@ from shutil import make_archive, unpack_archive, move
 import tempfile
 from datetime import datetime
 import quip.field_builder as fb
+import quip.version_builder as vb
 from argparse import RawTextHelpFormatter
 from colorama import Fore, Style, init
+from quip import __version__
 
-version = "1.4.4"
+version = __version__
 UPDATE_ACTION = ["update", "u", "up"]
 FIELD_ACTION = ["fields", "f", "fi"]
 ICON_ACTION = ["icon", "resize-icon", "ri", "resize"]
@@ -62,6 +64,7 @@ class Quip:
 
     def parse_arguments(self):
         parser = argparse.ArgumentParser(description='Wrapper for UIP command.', formatter_class=RawTextHelpFormatter)
+        parser.add_argument('--version', action='version', version=f'quip {version}')
         subparsers = parser.add_subparsers(dest='action')
         parser.add_argument('--config', '-c', default=None,
                              help='path of the global config. Default is ~/.uip_config.yml')
@@ -128,6 +131,11 @@ class Quip:
         parser_icon = subparsers.add_parser('clean', aliases=CLEAN_ACTION[1:], help='Clears the dist folders')
         parser_icon.add_argument('name', nargs="?", help='name of the project')
 
+        parser_icon = subparsers.add_parser('version', help='shows the version of the template/extension')
+        parser_icon.add_argument('version_method', nargs="?", choices=["minor", "major", "release"], help='update the version of the project. Options: minor,major,release.')
+        parser_icon.add_argument('--force', dest="forced_version", help='Force to change the version in all possible files')
+
+
         parser_icon = subparsers.add_parser('config', help='show the configuration')
 
 
@@ -139,7 +147,7 @@ class Quip:
             parser.print_help()
             sys.exit(0)
         
-        if args.action in ["config"]:
+        if args.action in ["config", "version"]:
             # give a fake name because name is mandatory
             args.name = ""
 
@@ -215,6 +223,30 @@ class Quip:
         elif action in CLEAN_ACTION:
             self.clean_project()
             sys.exit(0)
+        elif action == "version":
+            self.curr_version = vb.find_current_version(version_files=self._version_files)
+            if len(self.curr_version) == 0:
+                logging.warning("There is no version information found.")
+                cprint("There is no version information found.", color="red")
+                sys.exit(1)
+            
+            self.show_version(self.curr_version, self.args.version_method)
+            if self.args.version_method is not None:
+                if len(self.curr_version) > 1:
+                    logging.error("There are multiple versions. Fix that first.")
+                    sys.exit(1)
+                
+                self.update_version(self.args.version_method, self.curr_version[0])
+            
+            if self.args.forced_version is not None:
+                if len(self.curr_version) > 1:
+                    logging.warning(f"There are multiple versions but you forced to update them all to {self.args.forced_version}")
+                
+                for old_version in self.curr_version:
+                    if old_version == self.args.forced_version:
+                        continue
+                    self.update_version("forced", old_version, self.args.forced_version)
+                
 
     def set_global_configs(self, project_name, config_path=None):
         if config_path is not None:
@@ -225,6 +257,7 @@ class Quip:
         self._global_conf_defaults = self.uip_global_config.get("defaults", {})
         self._global_conf_extension = self.uip_global_config.get("extension.yml", {})
         self._global_conf_uip = self.uip_global_config.get("uip.yml", {})
+        self._version_files = self.uip_global_config.get("version_files", None)
         self.default_template = self._global_conf_defaults.get("template", "ue-task")
         self.project_name = self.format_ext_name(project_name)
         self.template_name = self.titleize(project_name)
@@ -631,6 +664,25 @@ class Quip:
             logging.debug(f"Archive file {archive_name}.zip moved to {build_folder}")
         return os.path.join(build_folder, archive_name + ".zip")
 
+    def show_version(self, current_versions, update):
+        cprint(f"Current Version {current_versions}", color="green")
+        if update is None:
+            print(f"Possible next versions:")
+            print(f"   RELEASE: ", vb.get_new_version("release", current_versions[0]))
+            print(f"   MAJOR: ", vb.get_new_version("major", current_versions[0]))
+            print(f"   MINOR: ", vb.get_new_version("minor", current_versions[0]))
+
+    def update_version(self, method, current_version, forced_version=None):
+        if forced_version is None:
+            new_version = vb.get_new_version(method, self.curr_version[0])
+        else:
+            new_version = forced_version
+        cprint(f"NEW Version will be {new_version}", color="green")
+        answer = self.yes_or_no(f"Do you want to update the versions from {current_version} to {new_version}? ", default=True)
+        if answer == True:
+            vb.update_version(current_version, new_version, version_files=self._version_files)
+
+
     def yes_or_no(self, question, default=None):
         if default == True:
             options = "(Y/n)"
